@@ -5,9 +5,9 @@ pub struct Empty<T, E>(E, PhantomData<T>);
 
 impl<T, E> ListFn for Empty<T, E> {
     type Item = T;
-    type End = Self;
+    type End = E;
     fn state(self) -> ListState<Self> {
-        ListState::End(self)
+        ListState::End(self.0)
     }
 }
 
@@ -16,10 +16,3 @@ impl<T, E> Empty<T, E> {
         Empty(e, PhantomData::default())
     }
 }
-
-impl<T, E> ResultFn for Empty<T, E> {
-    type Result = E;
-    fn result(self) -> E {
-        self.0
-    }
-}
